@@ -16,8 +16,8 @@ our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-our @EXPORT = qw(atomiza sentences separa_frases fsentences);
-our $VERSION = '0.02';
+our @EXPORT = qw(atomiza sentences separa_frases fsentences tokeniza);
+our $VERSION = '0.03';
 
 
 
@@ -95,13 +95,27 @@ sub tokenize{
     s/($protect)/savit($1)/xge;
     s!([\\]])!$1 !g;
     s#([\\[])# $1#g;
-    s#\"# \" #g;
+
+    # No tokenizer de Oslo usa-se  e  para distinguir entre abrir e fechar...
+    # Para isso...
+    # separa as aspas anteriores
+    s/ \"/ \ /g;
+    # separa as aspas posteriores
+    s/\"([ .?!:;,]?)/ \ $1/g;
+    # separa as aspas posteriores mesmo no fim
+    s/\"$/ \/g;
+
     s/(\s*\b\s*|\s+)/\n/g;
+
+    # s#\"# \" #g;
     # s/(.)\n-\n/$1-/g;
     s/\n+/\n/g;
     s/\n(\.?[])\b/$1/g;
     while ( s#\b([0-9]+)\n([\,.])\n([0-9]+\n)#$1$2$3#g ){};
     s#\n($abrev)\n\.\n#\n$1\.\n#ig;
+
+    s#([\]\)])([.,;:!?])#$1\n$2#g;
+
     s/\n*</\n</;
     $_=loadit($_);
     s/(\s*\n)+$/\n/;
@@ -340,8 +354,11 @@ sub tratar_pontuacao_interna {
     s/ ([lc])j\./ $1j+/g; # conjunto ou loja
     #    $par=~s/ al\./ al+/g; # alameda tem que ir para depois de et.al...
 
-    s/Tel(e[fm])*\./Tel$1+/g; # Tel., Telef., Telem.
-    s/ tel(e[fm])*\./ tel$1+/g; # tel., telef., telem.
+    # Remover aqui uns warningzitos
+    s/Tel\./Tel+/g; # Tel.
+    s/Tel(e[fm])\./Tel$1+/g; #  Telef., Telem.
+    s/ tel\./ tel+/g; # tel.
+    s/ tel(e[fm])\./ tel$1+/g; #  telef., telem.
     s/Fax\./Fax+/g; # Fax.
     s/ cx\./ cx+/g; # caixa
 
@@ -927,7 +944,8 @@ na lngua portuguesa. No entanto,  possvel que possa ser usado para
 outras lnguas.
 
 A forma simples de uso do atomizador  usando directamente a funo
-C<atomiza> que retorna um texto em que cada linha contm um tomo.
+C<atomiza> que retorna um texto em que cada linha contm um tomo, ou o
+uso da funo C<tokeniza> que contm outra verso de atomizador.
 
 =head2 Segmentao
 
@@ -957,6 +975,60 @@ frase por linha.
 Estas duas implementaes iro ser testadas e aglomeradas numa nica
 que permita ambas as funcionalidades.
 
+=head2 Segmentao a vrios nveis
+
+A funo C<fsentences> permite segmentar um conjunto de ficheiros a
+vrios nveis: por ficheiro, por pargrafo ou por frase. O output pode
+ser realizado em vrios formatos e obtendo, ou no, numerao de
+segmentos.
+
+Esta funo  invocada com uma referncia para um hash de configurao
+e uma lista de ficheiros a processar (no caso de a lista ser vazia,
+ir usar o C<STDIN>).
+
+O resultado do processamento  enviado para o C<STDOUT> a no ser que
+a chave C<output> do hash de configurao esteja definida. Nesse caso,
+o seu valor ser usado como ficheiro de resultado.
+
+A chave C<input_p_sep> permite definir o separador de pargrafos. Por
+omisso,  usada uma linha em branco.
+
+A chave C<o_format> define as polticas de etiquetao do
+resultado. De momento, a nica poltica disponvel  a C<XML>.
+
+As chaves C<s_tag>, C<p_tag> e C<t_tag> definem as etiquetas a usar,
+na poltica XML, para etiquetar frases, pargrafos e textos
+(ficheiros), respectivamente. Por omisso, as etiquetas usadas so
+C<s>, C<p> e C<text>.
+
+ possvel numerar as etiquetas, definindo as chaves C<s_num>,
+C<p_num> ou C<t_num> da seguinte forma:
+
+=over 4
+
+=item '0'
+
+Nenhuma numerao.
+
+=item 'f'
+
+S pode ser usado com o C<t_tag>, e define que as etiquetas que
+delimitam ficheiros usar o nome do ficheiro como identificador.
+
+=item '1'
+
+Numerao a um nvel. Cada etiqueta ter um contador diferente.
+
+=item '2'
+
+S pode ser usado com o C<p_tag> ou o C<s_tag> e obriga  numerao a
+dois nveis (N.N).
+
+=item '3'
+
+S pode ser usado com o C<s_tag> e obriga  numerao a trs nveis (N.N.N)
+
+=back
 
 =head1 SEE ALSO
 
